@@ -8,9 +8,10 @@ import time
 
 from cvise.passes.abstract import AbstractPass, BinaryState, PassResult
 
+
 class ClangBinarySearchPass(AbstractPass):
     def check_prerequisites(self):
-        return self.check_external_program("clang_delta")
+        return self.check_external_program('clang_delta')
 
     def detect_best_standard(self, test_case):
         best = None
@@ -43,7 +44,7 @@ class ClangBinarySearchPass(AbstractPass):
         return state
 
     def count_instances(self, test_case):
-        args = [self.external_programs["clang_delta"], "--query-instances={}".format(self.arg)]
+        args = [self.external_programs['clang_delta'], '--query-instances={}'.format(self.arg)]
         if self.clang_delta_std:
             args.append('--std={}'.format(self.clang_delta_std))
         cmd = args + [test_case]
@@ -53,7 +54,7 @@ class ClangBinarySearchPass(AbstractPass):
         except subprocess.SubprocessError:
             return 0
 
-        m = re.match("Available transformation instances: ([0-9]+)$", proc.stdout)
+        m = re.match('Available transformation instances: ([0-9]+)$', proc.stdout)
 
         if m is None:
             return 0
@@ -70,16 +71,16 @@ class ClangBinarySearchPass(AbstractPass):
                 pass
 
     def transform(self, test_case, state, process_event_notifier):
-        logging.debug("TRANSFORM: index = {}, chunk = {}, instances = {}".format(state.index, state.chunk, state.instances))
+        logging.debug('TRANSFORM: index = {}, chunk = {}, instances = {}'.format(state.index, state.chunk, state.instances))
 
         tmp = os.path.dirname(test_case)
         with tempfile.NamedTemporaryFile(mode='w', delete=False, dir=tmp) as tmp_file:
-            args = ["--transformation={}".format(self.arg), "--counter={}".format(state.index + 1), "--to-counter={}".format(state.end()),
-                    "--warn-on-counter-out-of-bounds", "--report-instances-count"]
+            args = ['--transformation={}'.format(self.arg), '--counter={}'.format(state.index + 1), '--to-counter={}'.format(state.end()),
+                    '--warn-on-counter-out-of-bounds', '--report-instances-count']
             if self.clang_delta_std:
                 args.append('--std={}'.format(self.clang_delta_std))
-            cmd = [self.external_programs["clang_delta"]] + args + [test_case]
-            logging.debug(" ".join(cmd))
+            cmd = [self.external_programs['clang_delta']] + args + [test_case]
+            logging.debug(' '.join(cmd))
 
             stdout, stderr, returncode = process_event_notifier.run_process(cmd)
             self.parse_stderr(state, stderr)
