@@ -1,39 +1,31 @@
-import asyncio
+from concurrent.futures import FIRST_COMPLETED, TimeoutError, wait
 import difflib
 import filecmp
-import importlib.util
 import logging
 import math
-import multiprocessing
+from multiprocessing import Manager
 import os
 import os.path
-import pebble
 import platform
-import psutil
 import shutil
-import subprocess
-import sys
 import tempfile
-import weakref
 import traceback
 
-import concurrent.futures
-from concurrent.futures import wait, FIRST_COMPLETED, TimeoutError
-from multiprocessing import Queue, Manager
-
-from .. import CVise
-from cvise.passes.abstract import *
-
-from . import readkey
-from .error import InsaneTestCaseError
-from .error import InvalidInterestingnessTestError
-from .error import InvalidTestCaseError
-from .error import PassBugError
-from .error import ZeroSizeError
+from cvise.cvise import CVise
+from cvise.passes.abstract import PassResult, ProcessEventNotifier, ProcessEventType
+from cvise.utils.error import InsaneTestCaseError
+from cvise.utils.error import InvalidInterestingnessTestError
+from cvise.utils.error import InvalidTestCaseError
+from cvise.utils.error import PassBugError
+from cvise.utils.error import ZeroSizeError
+from cvise.utils.readkey import KeyLogger
+import pebble
+import psutil
 
 # change default Pebble sleep unit for faster response
 pebble.common.SLEEP_UNIT = 0.01
 
+
 def rmfolder(name):
     assert 'cvise' in name
     try:
@@ -41,9 +33,10 @@ def rmfolder(name):
     except OSError:
         pass
 
+
 class TestEnvironment:
     def __init__(self, state, order, test_script, folder, test_case,
-            additional_files, transform, pid_queue=None):
+                 additional_files, transform, pid_queue=None):
         self.test_case = None
         self.additional_files = set()
         self.state = state
@@ -100,7 +93,7 @@ class TestEnvironment:
         try:
             # transform by state
             (result, self.state) = self.transform(self.test_case_path, self.state,
-                    ProcessEventNotifier(self.pid_queue))
+                                                  ProcessEventNotifier(self.pid_queue))
             self.result = result
             if self.result != PassResult.OK:
                 return self
@@ -108,13 +101,12 @@ class TestEnvironment:
             # run test script
             self.exitcode = self.run_test(False)
             return self
-        except OSError as e:
+        except OSError:
             # this can happen when we clean up temporary files for cancelled processes
-            pass
+            return self
         except Exception as e:
             print('Unexpected TestEnvironment::run failure: ' + str(e))
             traceback.print_exc()
-        finally:
             return self
 
     def run_test(self, verbose):
@@ -128,16 +120,17 @@ class TestEnvironment:
             os.chdir(self.pwd)
         return returncode
 
+
 class TestManager:
     GIVEUP_CONSTANT = 50000
     MAX_TIMEOUTS = 20
     MAX_CRASH_DIRS = 10
     MAX_EXTRA_DIRS = 25000
-    TEMP_PREFIX = "cvise-"
+    TEMP_PREFIX = 'cvise-'
 
     def __init__(self, pass_statistic, test_script, timeout, save_temps, test_cases, parallel_tests,
-            no_cache, skip_key_off, silent_pass_bug, die_on_pass_bug, print_diff, max_improvement,
-            no_give_up, also_interesting):
+                 no_cache, skip_key_off, silent_pass_bug, die_on_pass_bug, print_diff, max_improvement,
+                 no_give_up, also_interesting):
         self.test_script = os.path.abspath(test_script)
         self.timeout = timeout
         self.save_temps = save_temps
@@ -185,15 +178,27 @@ class TestManager:
 
     @property
     def sorted_test_cases(self):
-        return sorted(self.test_cases, key=os.path.getsize)
+        return sorted(self.test_cases, key=os.path.getsize, reverse=True)
 
     @staticmethod
     def get_file_size(files):
         return sum(os.path.getsize(f) for f in files)
 
+    @property
+    def total_line_count(self):
+        return self.get_line_count(self.test_cases)
+
+    @staticmethod
+    def get_line_count(files):
+        lines = 0
+        for file in files:
+            with open(file) as f:
+                lines += len(f.readlines())
+        return lines
+
     def backup_test_cases(self):
         for f in self.test_cases:
-            orig_file = "{}.orig".format(f)
+            orig_file = '{}.orig'.format(f)
 
             if not os.path.exists(orig_file):
                 # Copy file and preserve attributes
@@ -214,7 +219,7 @@ class TestManager:
     def get_extra_dir(prefix, max_number):
         for i in range(0, max_number + 1):
             digits = int(round(math.log10(max_number), 0))
-            extra_dir = ("{0}{1:0" + str(digits) + "d}").format(prefix, i)
+            extra_dir = ('{0}{1:0' + str(digits) + 'd}').format(prefix, i)
 
             if not os.path.exists(extra_dir):
                 break
@@ -228,24 +233,24 @@ class TestManager:
 
     def report_pass_bug(self, test_env, problem):
         if not self.die_on_pass_bug:
-            logging.warning("{} has encountered a non fatal bug: {}".format(self.current_pass, problem))
+            logging.warning('{} has encountered a non fatal bug: {}'.format(self.current_pass, problem))
 
-        crash_dir = self.get_extra_dir("cvise_bug_", self.MAX_CRASH_DIRS)
+        crash_dir = self.get_extra_dir('cvise_bug_', self.MAX_CRASH_DIRS)
 
-        if crash_dir == None:
+        if crash_dir is None:
             return
 
         os.mkdir(crash_dir)
         test_env.dump(crash_dir)
 
         if not self.die_on_pass_bug:
-            logging.debug("Please consider tarring up {} and creating an issue at https://github.com/marxin/cvise/issues and we will try to fix the bug.".format(crash_dir))
+            logging.debug('Please consider tarring up {} and creating an issue at https://github.com/marxin/cvise/issues and we will try to fix the bug.'.format(crash_dir))
 
-        with open(os.path.join(crash_dir, "PASS_BUG_INFO.TXT"), mode="w") as info_file:
-            info_file.write("Package: %s\n" % CVise.Info.PACKAGE_STRING)
-            info_file.write("Git version: %s\n" % CVise.Info.GIT_VERSION)
-            info_file.write("LLVM version: %s\n" % CVise.Info.LLVM_VERSION)
-            info_file.write("System: %s\n" % str(platform.uname()))
+        with open(os.path.join(crash_dir, 'PASS_BUG_INFO.TXT'), mode='w') as info_file:
+            info_file.write('Package: %s\n' % CVise.Info.PACKAGE_STRING)
+            info_file.write('Git version: %s\n' % CVise.Info.GIT_VERSION)
+            info_file.write('LLVM version: %s\n' % CVise.Info.LLVM_VERSION)
+            info_file.write('System: %s\n' % str(platform.uname()))
             info_file.write(PassBugError.MSG.format(self.current_pass, problem, test_env.state, crash_dir))
 
         if self.die_on_pass_bug:
@@ -261,19 +266,19 @@ class TestManager:
 
         diffed_lines = difflib.unified_diff(orig_file_lines, changed_file_lines, orig_file, changed_file)
 
-        return "".join(diffed_lines)
+        return ''.join(diffed_lines)
 
     def check_sanity(self, verbose=False):
-        logging.debug("perform sanity check... ")
+        logging.debug('perform sanity check... ')
 
         folder = tempfile.mkdtemp(prefix=self.TEMP_PREFIX)
         test_env = TestEnvironment(None, 0, self.test_script, folder, None, self.test_cases, None)
-        logging.debug("sanity check tmpdir = {}".format(test_env.folder))
+        logging.debug('sanity check tmpdir = {}'.format(test_env.folder))
 
         returncode = test_env.run_test(verbose)
         if returncode == 0:
             rmfolder(folder)
-            logging.debug("sanity check successful")
+            logging.debug('sanity check successful')
         else:
             if not self.save_temps:
                 rmfolder(folder)
@@ -291,7 +296,7 @@ class TestManager:
 
     @classmethod
     def log_key_event(cls, event):
-        logging.info("****** %s  ******" % event)
+        logging.info('****** %s  ******' % event)
 
     def kill_pid_queue(self):
         active_pids = set()
@@ -319,11 +324,11 @@ class TestManager:
         self.release_folder(future)
 
     def save_extra_dir(self, test_case_path):
-        extra_dir = self.get_extra_dir("cvise_extra_", self.MAX_EXTRA_DIRS)
-        if extra_dir != None:
+        extra_dir = self.get_extra_dir('cvise_extra_', self.MAX_EXTRA_DIRS)
+        if extra_dir is not None:
             os.mkdir(extra_dir)
             shutil.move(test_case_path, extra_dir)
-            logging.info("Created extra directory {} for you to look at later".format(extra_dir))
+            logging.info('Created extra directory {} for you to look at later'.format(extra_dir))
 
     def process_done_futures(self):
         quit_loop = False
@@ -338,10 +343,10 @@ class TestManager:
                 if future.exception():
                     if type(future.exception()) is TimeoutError:
                         self.timeout_count += 1
-                        logging.warning("Test timed out.")
+                        logging.warning('Test timed out.')
                         self.save_extra_dir(self.temporary_folders[future])
                         if self.timeout_count >= self.MAX_TIMEOUTS:
-                            logging.warning("Maximum number of timeout were reached: %d" % self.MAX_TIMEOUTS)
+                            logging.warning('Maximum number of timeout were reached: %d' % self.MAX_TIMEOUTS)
                             quit_loop = True
                         continue
                     else:
@@ -350,13 +355,13 @@ class TestManager:
                 test_env = future.result()
                 if test_env.success:
                     if (self.max_improvement is not None and
-                        test_env.size_improvement > self.max_improvement):
-                        logging.debug("Too large improvement: {} B".format(test_env.size_improvement))
+                            test_env.size_improvement > self.max_improvement):
+                        logging.debug('Too large improvement: {} B'.format(test_env.size_improvement))
                     else:
                         # Report bug if transform did not change the file
                         if filecmp.cmp(self.current_test_case, test_env.test_case_path):
                             if not self.silent_pass_bug:
-                                self.report_pass_bug(test_env, "pass failed to modify the variant")
+                                self.report_pass_bug(test_env, 'pass failed to modify the variant')
                         else:
                             quit_loop = True
                             new_futures.add(future)
@@ -365,28 +370,28 @@ class TestManager:
                     if test_env.result == PassResult.OK:
                         assert test_env.exitcode
                         if (self.also_interesting is not None and
-                            test_env.exitcode == self.also_interesting):
+                                test_env.exitcode == self.also_interesting):
                             self.save_extra_dir(test_env.test_case_path)
                     elif test_env.result == PassResult.STOP:
                         quit_loop = True
                     elif test_env.result == PassResult.ERROR:
                         if not self.silent_pass_bug:
-                            self.report_pass_bug(test_env, "pass error")
+                            self.report_pass_bug(test_env, 'pass error')
                             quit_loop = True
                     if not self.no_give_up and test_env.order > self.GIVEUP_CONSTANT:
-                        self.report_pass_bug(test_env, "pass got stuck")
+                        self.report_pass_bug(test_env, 'pass got stuck')
                         quit_loop = True
             else:
                 new_futures.add(future)
 
-        removed_futures = [f for f in self.futures if not f in new_futures]
+        removed_futures = [f for f in self.futures if f not in new_futures]
         for f in removed_futures:
             self.release_future(f)
 
         return quit_loop
 
     def wait_for_first_success(self):
-        for i, future in enumerate(self.futures):
+        for future in self.futures:
             try:
                 test_env = future.result()
                 if test_env.success:
@@ -406,7 +411,7 @@ class TestManager:
         with pebble.ProcessPool(max_workers=self.parallel_tests) as pool:
             order = 1
             self.timeout_count = 0
-            while self.state != None:
+            while self.state is not None:
                 # do not create too many states
                 if len(self.futures) >= self.parallel_tests:
                     wait(self.futures, return_when=FIRST_COMPLETED)
@@ -419,8 +424,8 @@ class TestManager:
 
                 folder = tempfile.mkdtemp(prefix=self.TEMP_PREFIX, dir=self.root)
                 test_env = TestEnvironment(self.state, order, self.test_script, folder,
-                        self.current_test_case, self.test_cases ^ {self.current_test_case},
-                        self.current_pass.transform, self.pid_queue)
+                                           self.current_test_case, self.test_cases ^ {self.current_test_case},
+                                           self.current_pass.transform, self.pid_queue)
                 future = pool.schedule(test_env.run, timeout=self.timeout)
                 self.temporary_folders[future] = folder
                 self.futures.append(future)
@@ -428,7 +433,7 @@ class TestManager:
                 order += 1
                 state = self.current_pass.advance(self.current_test_case, self.state)
                 # we are at the end of enumeration
-                if state == None:
+                if state is None:
                     success = self.wait_for_first_success()
                     self.terminate_all(pool)
                     return success
@@ -444,46 +449,46 @@ class TestManager:
         self.create_root()
         pass_key = repr(self.current_pass)
 
-        logging.info("===< {} >===".format(self.current_pass))
+        logging.info('===< {} >==='.format(self.current_pass))
 
         if self.total_file_size == 0:
             raise ZeroSizeError(self.test_cases)
 
         self.pass_statistic.start(self.current_pass)
         if not self.skip_key_off:
-            logger = readkey.KeyLogger()
+            logger = KeyLogger()
 
-        for test_case in self.test_cases:
+        for test_case in self.sorted_test_cases:
             self.current_test_case = test_case
 
             if self.get_file_size([test_case]) == 0:
                 continue
 
             if not self.no_cache:
-                with open(test_case, mode="r+") as tmp_file:
+                with open(test_case, mode='r+') as tmp_file:
                     test_case_before_pass = tmp_file.read()
 
                     if (pass_key in self.cache and
-                        test_case_before_pass in self.cache[pass_key]):
+                            test_case_before_pass in self.cache[pass_key]):
                         tmp_file.seek(0)
                         tmp_file.truncate(0)
                         tmp_file.write(self.cache[pass_key][test_case_before_pass])
-                        logging.info("cache hit for {}".format(test_case))
+                        logging.info('cache hit for {}'.format(test_case))
                         continue
 
             # create initial state
             self.state = self.current_pass.new(self.current_test_case, self.check_sanity)
             self.skip = False
 
-            while self.state != None and not self.skip:
+            while self.state is not None and not self.skip:
                 # Ignore more key presses after skip has been detected
                 if not self.skip_key_off and not self.skip:
                     key = logger.pressed_key()
-                    if key == "s":
+                    if key == 's':
                         self.skip = True
-                        self.log_key_event("skipping the rest of this pass")
-                    elif key == "d":
-                        self.log_key_event("toggle print diff")
+                        self.log_key_event('skipping the rest of this pass')
+                    elif key == 'd':
+                        self.log_key_event('toggle print diff')
                         self.print_diff = not self.print_diff
 
                 success_env = self.run_parallel_tests()
@@ -498,7 +503,7 @@ class TestManager:
 
             # Cache result of this pass
             if not self.no_cache:
-                with open(test_case, mode="r") as tmp_file:
+                with open(test_case, mode='r') as tmp_file:
                     if pass_key not in self.cache:
                         self.cache[pass_key] = {}
 
@@ -518,4 +523,4 @@ class TestManager:
         self.pass_statistic.add_success(self.current_pass)
 
         pct = 100 - (self.total_file_size * 100.0 / self.orig_total_file_size)
-        logging.info("({}%, {} bytes)".format(round(pct, 1), self.total_file_size))
+        logging.info('({}%, {} bytes, {} lines)'.format(round(pct, 1), self.total_file_size, self.total_line_count))
